@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2019 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the QtQuick module of the Qt Toolkit.
@@ -73,7 +73,7 @@ class QQuickFlickableVisibleArea;
 class QQuickTransition;
 class QQuickFlickableReboundTransition;
 
-class Q_AUTOTEST_EXPORT QQuickFlickablePrivate : public QQuickItemPrivate, public QQuickItemChangeListener
+class Q_QUICK_PRIVATE_EXPORT QQuickFlickablePrivate : public QQuickItemPrivate, public QQuickItemChangeListener
 {
     Q_DECLARE_PUBLIC(QQuickFlickable)
 
@@ -206,6 +206,8 @@ public:
 
     void cancelInteraction();
 
+    void addPointerHandler(QQuickPointerHandler *h) override;
+
 public:
     QQuickItem *contentItem;
 
@@ -221,8 +223,8 @@ public:
     bool interactive : 1;
     bool calcVelocity : 1;
     bool pixelAligned : 1;
+    bool syncDrag : 1;
     QElapsedTimer timer;
-    QBasicTimer movementEndingTimer;
     qint64 lastPosTime;
     qint64 lastPressTime;
     QPointF lastPos;
@@ -282,6 +284,7 @@ class QQuickFlickableVisibleArea : public QObject
     Q_PROPERTY(qreal yPosition READ yPosition NOTIFY yPositionChanged)
     Q_PROPERTY(qreal widthRatio READ widthRatio NOTIFY widthRatioChanged)
     Q_PROPERTY(qreal heightRatio READ heightRatio NOTIFY heightRatioChanged)
+    QML_ANONYMOUS
 
 public:
     QQuickFlickableVisibleArea(QQuickFlickable *parent=nullptr);
